@@ -276,7 +276,7 @@ class UserContextTag(Tag):
 
             try:
                 user_id = int(user_id)
-            except TypeError:
+            except (TypeError, ValueError):
                 return ''
 
             context = self.ui.renderer.context
@@ -285,14 +285,17 @@ class UserContextTag(Tag):
             if fetchUsers := self.first_ancestor('fetchUsers'):
                 
                 # member is not guaranteed to exist here
-                member = fetchUsers.get_state(user_id)
-                # saves the member info in root for future use,
-                # in case the member leaves the server
-                self.root.update_state({
-                    user_id: self.get_member_info(member)
-                })
+                if member := fetchUsers.get_state(user_id):
+                    # saves the member info in root for future use,
+                    # in case the member leaves the server
+                    self.root.update_state({
+                        user_id: self.get_member_info(member)
+                    })
 
-                member_info = self.get_member_info(member)
+                    member_info = self.get_member_info(member)
+
+                else:
+                    return ''
 
             elif member := await context.guild.fetch_member(user_id):
                 member_info = self.get_member_info(member)
